import {
  Column,
  Entity,
  Index,
  JoinColumn,
  ManyToOne,
  OneToMany,
  Unique,
} from 'typeorm';
import { AbstractEntity } from '../../abstract/entities/abstract.entity';
import { PermissionTypeEntity } from '../../permission/entities';
import { PowerClampHourlyEntity } from '../../power-clamp/entities/power-clamp.entity';
import { PresenceSensorDailyDeviceEntity } from '../../presence-sensor/entities';
import { ProductEntity } from '../../product/entities';
import { SceneDeviceEntity } from '../../scene-device/entities';
import { SpaceEntity } from '../../space/entities/space.entity';
import { SubspaceEntity } from '../../space/entities/subspace/subspace.entity';
import { NewTagEntity } from '../../tag';
import { UserEntity } from '../../user/entities';
import { DeviceNotificationDto } from '../dtos';
import { DeviceDto, DeviceUserPermissionDto } from '../dtos/device.dto';

@Entity({ name: 'device' })
@Unique(['deviceTuyaUuid'])
export class DeviceEntity extends AbstractEntity<DeviceDto> {
  @Column({
    nullable: false,
  })
  deviceTuyaUuid: string;

  @Column({
    nullable: true,
  })
  deviceTuyaConstUuid: string;

  @Column({
    nullable: true,
    default: true,
    type: 'boolean',
  })
  isActive: boolean;
  @Column({
    nullable: false,
  })
  name: string;
  @OneToMany(
    () => DeviceUserPermissionEntity,
    (permission) => permission.device,
    {
      nullable: true,
    },
  )
  permission: DeviceUserPermissionEntity[];
  @OneToMany(
    () => DeviceNotificationEntity,
    (deviceUserNotification) => deviceUserNotification.device,
    {
      nullable: true,
    },
  )
  deviceUserNotification: DeviceNotificationEntity[];

  @ManyToOne(() => SpaceEntity, (space) => space.devices, {
    nullable: true,
  })
  spaceDevice: SpaceEntity;

  @ManyToOne(() => ProductEntity, (product) => product.devicesProductEntity, {
    nullable: false,
  })
  productDevice: ProductEntity;

  @ManyToOne(() => SubspaceEntity, (subspace) => subspace.devices, {
    nullable: true,
  })
  @JoinColumn({ name: 'subspace_id' })
  subspace: SubspaceEntity;

  @Index()
  @Column({ nullable: false })
  uuid: string;

  @OneToMany(() => SceneDeviceEntity, (sceneDevice) => sceneDevice.device, {})
  sceneDevices: SceneDeviceEntity[];

  @ManyToOne(() => NewTagEntity, (tag) => tag.devices)
  @JoinColumn({ name: 'tag_uuid' })
  public tag: NewTagEntity;
  @OneToMany(() => PowerClampHourlyEntity, (powerClamp) => powerClamp.device)
  powerClampHourly: PowerClampHourlyEntity[];
  @OneToMany(() => PresenceSensorDailyDeviceEntity, (sensor) => sensor.device)
  presenceSensorDaily: PresenceSensorDailyDeviceEntity[];
  constructor(partial: Partial<DeviceEntity>) {
    super();
    Object.assign(this, partial);
  }
}

@Entity({ name: 'device-notification' })
@Unique(['userUuid', 'deviceUuid'])
export class DeviceNotificationEntity extends AbstractEntity<DeviceNotificationDto> {
  @Column({
    nullable: false,
  })
  public userUuid: string;

  @Column({
    nullable: false,
  })
  deviceUuid: string;

  @ManyToOne(() => DeviceEntity, (device) => device.permission, {
    nullable: false,
  })
  device: DeviceEntity;

  @ManyToOne(() => UserEntity, (user) => user.userPermission, {
    nullable: false,
    onDelete: 'CASCADE',
  })
  user: UserEntity;

  constructor(partial: Partial<DeviceNotificationEntity>) {
    super();
    Object.assign(this, partial);
  }
}

@Entity({ name: 'device-user-permission' })
@Unique(['userUuid', 'deviceUuid'])
export class DeviceUserPermissionEntity extends AbstractEntity<DeviceUserPermissionDto> {
  @Column({
    nullable: false,
  })
  public userUuid: string;

  @Column({
    nullable: false,
  })
  deviceUuid: string;

  @ManyToOne(() => DeviceEntity, (device) => device.permission, {
    nullable: false,
  })
  device: DeviceEntity;

  @ManyToOne(
    () => PermissionTypeEntity,
    (permissionType) => permissionType.permission,
    {
      nullable: false,
    },
  )
  permissionType: PermissionTypeEntity;

  @ManyToOne(() => UserEntity, (user) => user.userPermission, {
    nullable: false,
    onDelete: 'CASCADE',
  })
  user: UserEntity;
  constructor(partial: Partial<DeviceUserPermissionEntity>) {
    super();
    Object.assign(this, partial);
  }
}
