import { Column, Entity, ManyToOne, Unique } from 'typeorm';
import { AbstractEntity } from '../../abstract/entities/abstract.entity';
import { PowerClampDto } from '../dtos';
import { DeviceEntity } from '../../device/entities/device.entity';

@Entity({ name: 'power-clamp-energy-consumed-hourly' })
@Unique(['deviceUuid', 'date', 'hour'])
export class PowerClampHourlyEntity extends AbstractEntity<PowerClampDto> {
  @Column({ nullable: false })
  public deviceUuid: string;

  @Column({ nullable: false })
  public hour: string;

  @Column({ nullable: false, type: 'date' })
  public date: string;

  @Column({ nullable: true })
  public energyConsumedKw: string;

  @Column({ nullable: false })
  public energyConsumedA: string;

  @Column({ nullable: false })
  public energyConsumedB: string;

  @Column({ nullable: false })
  public energyConsumedC: string;

  @ManyToOne(() => DeviceEntity, (device) => device.powerClampHourly)
  device: DeviceEntity;

  constructor(partial: Partial<PowerClampHourlyEntity>) {
    super();
    Object.assign(this, partial);
  }
}
@Entity({ name: 'power-clamp-energy-consumed-daily' })
@Unique(['deviceUuid', 'date'])
export class PowerClampDailyEntity extends AbstractEntity<PowerClampDto> {
  @Column({ nullable: false })
  public deviceUuid: string;

  @Column({ nullable: false, type: 'date' })
  public date: string;

  @Column({ nullable: true })
  public energyConsumedKw: string;

  @Column({ nullable: false })
  public energyConsumedA: string;

  @Column({ nullable: false })
  public energyConsumedB: string;

  @Column({ nullable: false })
  public energyConsumedC: string;

  @ManyToOne(() => DeviceEntity, (device) => device.powerClampHourly)
  device: DeviceEntity;

  constructor(partial: Partial<PowerClampHourlyEntity>) {
    super();
    Object.assign(this, partial);
  }
}
@Entity({ name: 'power-clamp-energy-consumed-monthly' })
@Unique(['deviceUuid', 'month'])
export class PowerClampMonthlyEntity extends AbstractEntity<PowerClampDto> {
  @Column({ nullable: false })
  public deviceUuid: string;

  @Column({ nullable: false })
  public month: string;

  @Column({ nullable: true })
  public energyConsumedKw: string;

  @Column({ nullable: false })
  public energyConsumedA: string;

  @Column({ nullable: false })
  public energyConsumedB: string;

  @Column({ nullable: false })
  public energyConsumedC: string;

  @ManyToOne(() => DeviceEntity, (device) => device.powerClampHourly)
  device: DeviceEntity;

  constructor(partial: Partial<PowerClampHourlyEntity>) {
    super();
    Object.assign(this, partial);
  }
}
