import { ControllerRoute } from '@app/common/constants/controller-route';
import { EnableDisableStatusEnum } from '@app/common/constants/days.enum';
import { Controller, Get, Param, UseGuards } from '@nestjs/common';
import { ApiBearerAuth, ApiOperation, ApiTags } from '@nestjs/swagger';
import { AutomationService } from '../services';
import { Permissions } from 'src/decorators/permissions.decorator';
import { PermissionsGuard } from 'src/guards/permissions.guard';
import { GetSpaceParam } from '@app/common/dto/get.space.param';

@ApiTags('Automation Module')
@Controller({
  version: EnableDisableStatusEnum.ENABLED,
  path: ControllerRoute.AUTOMATION_SPACE.ROUTE,
})
export class AutomationSpaceController {
  constructor(private readonly automationService: AutomationService) {}

  @ApiBearerAuth()
  @UseGuards(PermissionsGuard)
  @Permissions('AUTOMATION_VIEW')
  @Get()
  @ApiOperation({
    summary:
      ControllerRoute.AUTOMATION_SPACE.ACTIONS.GET_AUTOMATION_BY_SPACE_SUMMARY,
    description:
      ControllerRoute.AUTOMATION_SPACE.ACTIONS
        .GET_AUTOMATION_BY_SPACE_DESCRIPTION,
  })
  async getAutomationBySpace(@Param() param: GetSpaceParam) {
    const automation = await this.automationService.getAutomationBySpace(param);
    return automation;
  }
}
