import { Module } from '@nestjs/common';
import { CommunityService } from './services/community.service';
import { CommunityController } from './controllers/community.controller';
import { ConfigModule } from '@nestjs/config';
import { SpaceRepositoryModule } from '@app/common/modules/space/space.repository.module';
import {
  InviteSpaceRepository,
  SpaceProductAllocationRepository,
  SpaceRepository,
} from '@app/common/modules/space/repositories';
import { UserSpaceRepository } from '@app/common/modules/user/repositories';
import { UserRepositoryModule } from '@app/common/modules/user/user.repository.module';
import { SpacePermissionService } from '@app/common/helper/services';
import { CommunityRepository } from '@app/common/modules/community/repositories';
import { TuyaService } from '@app/common/integrations/tuya/services/tuya.service';
import { ProjectRepository } from '@app/common/modules/project/repositiories';
import {
  SpaceService,
  SubspaceDeviceService,
  SubSpaceService,
  ValidationService,
} from 'src/space/services';
import { TagService as NewTagService } from 'src/tags/services';
import {
  SpaceModelService,
  SubSpaceModelService,
} from 'src/space-model/services';
import { SpaceProductAllocationService } from 'src/space/services/space-product-allocation.service';
import {
  SubspaceProductAllocationRepository,
  SubspaceRepository,
} from '@app/common/modules/space/repositories/subspace.repository';
import { SubspaceProductAllocationService } from 'src/space/services/subspace/subspace-product-allocation.service';
import {
  SpaceModelProductAllocationRepoitory,
  SpaceModelRepository,
  SubspaceModelProductAllocationRepoitory,
  SubspaceModelRepository,
} from '@app/common/modules/space-model';
import { DeviceRepository } from '@app/common/modules/device/repositories';
import { NewTagRepository } from '@app/common/modules/tag/repositories/tag-repository';
import { ProductRepository } from '@app/common/modules/product/repositories';
import { SpaceModelProductAllocationService } from 'src/space-model/services/space-model-product-allocation.service';
import { SubspaceModelProductAllocationService } from 'src/space-model/services/subspace/subspace-model-product-allocation.service';
import { DeviceService } from 'src/device/services';
import { SceneDeviceRepository } from '@app/common/modules/scene-device/repositories';
import { DeviceStatusFirebaseService } from '@app/common/firebase/devices-status/services/devices-status.service';
import { SceneService } from 'src/scene/services';
import { DeviceStatusLogRepository } from '@app/common/modules/device-status-log/repositories';
import {
  SceneIconRepository,
  SceneRepository,
} from '@app/common/modules/scene/repositories';
import { AutomationRepository } from '@app/common/modules/automation/repositories';
import { PowerClampService } from '@app/common/helper/services/power.clamp.service';
import {
  PowerClampHourlyRepository,
  PowerClampDailyRepository,
  PowerClampMonthlyRepository,
} from '@app/common/modules/power-clamp/repositories';
import { SqlLoaderService } from '@app/common/helper/services/sql-loader.service';
import { OccupancyService } from '@app/common/helper/services/occupancy.service';
import { AqiDataService } from '@app/common/helper/services/aqi.data.service';
import { PresenceSensorDailySpaceRepository } from '@app/common/modules/presence-sensor/repositories';
import { AqiSpaceDailyPollutantStatsRepository } from '@app/common/modules/aqi/repositories';

@Module({
  imports: [ConfigModule, SpaceRepositoryModule, UserRepositoryModule],
  controllers: [CommunityController],
  providers: [
    CommunityService,
    SpaceRepository,
    UserSpaceRepository,
    TuyaService,
    CommunityRepository,
    SpacePermissionService,
    ProjectRepository,
    SpaceService,
    InviteSpaceRepository,
    // Todo: find out why this is needed
    SubSpaceService,
    ValidationService,
    NewTagService,
    SpaceModelService,
    SpaceProductAllocationService,
    SubspaceRepository,
    // Todo: find out why this is needed
    SubspaceDeviceService,
    SubspaceProductAllocationService,
    SpaceModelRepository,
    DeviceRepository,
    NewTagRepository,
    ProductRepository,
    SubSpaceModelService,
    SpaceModelProductAllocationService,
    SpaceProductAllocationRepository,
    SubspaceProductAllocationRepository,
    SubspaceModelRepository,
    SubspaceModelProductAllocationService,
    SpaceModelProductAllocationRepoitory,
    SubspaceModelProductAllocationRepoitory,
    DeviceService,
    SceneDeviceRepository,
    DeviceStatusFirebaseService,
    SceneService,
    DeviceStatusLogRepository,
    SceneIconRepository,
    SceneRepository,
    AutomationRepository,
    PowerClampService,
    PowerClampHourlyRepository,
    PowerClampDailyRepository,
    PowerClampMonthlyRepository,
    SqlLoaderService,
    OccupancyService,
    AqiDataService,
    PresenceSensorDailySpaceRepository,
    AqiSpaceDailyPollutantStatsRepository,
  ],
  exports: [CommunityService, SpacePermissionService],
})
export class CommunityModule {}
