import { Controller, Get, HttpStatus } from '@nestjs/common';
import { ApiOperation, ApiTags } from '@nestjs/swagger';
import { EnableDisableStatusEnum } from '@app/common/constants/days.enum';
import { ControllerRoute } from '@app/common/constants/controller-route'; // Assuming this is where the routes are defined
import { PrivacyPolicyService } from '../services';

@ApiTags('Privacy Policy Module')
@Controller({
  version: EnableDisableStatusEnum.ENABLED,
  path: ControllerRoute.PRIVACY_POLICY.ROUTE,
})
export class PrivacyPolicyController {
  constructor(private readonly privacyPolicyService: PrivacyPolicyService) {}

  @Get()
  @ApiOperation({
    summary: ControllerRoute.PRIVACY_POLICY.ACTIONS.FETCH_POLICY_SUMMARY,
    description:
      ControllerRoute.PRIVACY_POLICY.ACTIONS.FETCH_POLICY_DESCRIPTION,
  })
  async fetchPrivacyPolicy() {
    const htmlContent = await this.privacyPolicyService.fetchPrivacyPolicy();
    return {
      statusCode: HttpStatus.OK,
      message: 'Privacy policy fetched successfully',
      data: htmlContent,
    };
  }
}
