import { termsAndConditionsData } from '@app/common/constants/terms-condtions';
import { Injectable } from '@nestjs/common';
import * as fs from 'fs';
import * as path from 'path';

@Injectable()
export class TermsAndConditionsService {
  async fetchTermsAndConditions(): Promise<string> {
    const projectRoot = process.cwd();

    const filePath = path.join(
      projectRoot,
      'libs',
      'common',
      'src',
      'constants',
      'terms-and-conditions.html',
    );

    // Ensure the file exists
    if (!fs.existsSync(filePath)) {
      throw new Error(`File not found: ${filePath}`);
    }

    let htmlContent = fs.readFileSync(filePath, 'utf-8');

    htmlContent = htmlContent.replace(/(\r\n|\n|\r)/gm, ''); // Removes newlines

    htmlContent = htmlContent
      .replace(/{{lastUpdated}}/g, termsAndConditionsData.lastUpdated)
      .replace(/{{websiteUrl}}/g, termsAndConditionsData.websiteUrl)
      .replace(/{{mobileApp}}/g, termsAndConditionsData.mobileApp)
      .replace(/{{companyName}}/g, termsAndConditionsData.companyName)
      .replace(/{{contactEmail}}/g, termsAndConditionsData.contactEmail);

    return htmlContent;
  }
}
