import { ControllerRoute } from '@app/common/constants/controller-route';
import { EnableDisableStatusEnum } from '@app/common/constants/days.enum';
import { Controller, Get, Param, UseGuards } from '@nestjs/common';
import { ApiBearerAuth, ApiOperation, ApiTags } from '@nestjs/swagger';
import { UserSpaceService } from '../services';
import { JwtAuthGuard } from '@app/common/guards/jwt.auth.guard';
import { BaseResponseDto } from '@app/common/dto/base.response.dto';
import { UserParamDto } from '../dtos';

@ApiTags('User Module')
@Controller({
  version: EnableDisableStatusEnum.ENABLED,
  path: ControllerRoute.USER_SPACE.ROUTE,
})
export class UserSpaceController {
  constructor(private readonly userSpaceService: UserSpaceService) {}

  @ApiBearerAuth()
  @UseGuards(JwtAuthGuard)
  @Get()
  @ApiOperation({
    summary: ControllerRoute.USER_SPACE.ACTIONS.GET_USER_SPACES_SUMMARY,
    description: ControllerRoute.USER_SPACE.ACTIONS.GET_USER_SPACES_DESCRIPTION,
  })
  async getSpacesForUser(
    @Param() params: UserParamDto,
  ): Promise<BaseResponseDto> {
    return this.userSpaceService.getSpacesForUser(params.userUuid);
  }
}
